==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetGatewayRouteSpecHttpRouteActionRewrite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property hostnames
 * @property paths
 * @property prefixes
 */
public data class GetGatewayRouteSpecHttpRouteActionRewrite(
    public val hostnames: List<GetGatewayRouteSpecHttpRouteActionRewriteHostname>,
    public val paths: List<GetGatewayRouteSpecHttpRouteActionRewritePath>,
    public val prefixes: List<GetGatewayRouteSpecHttpRouteActionRewritePrefix>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetGatewayRouteSpecHttpRouteActionRewrite):
            GetGatewayRouteSpecHttpRouteActionRewrite = GetGatewayRouteSpecHttpRouteActionRewrite(
            hostnames = javaType.hostnames().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttpRouteActionRewriteHostname.Companion.toKotlin(args0)
                })
            }),
            paths = javaType.paths().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttpRouteActionRewritePath.Companion.toKotlin(args0)
                })
            }),
            prefixes = javaType.prefixes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttpRouteActionRewritePrefix.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetGatewayRouteSpecHttpRouteActionRewrite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property hostnames
 * @property paths
 * @property prefixes
 */
public data class GetGatewayRouteSpecHttpRouteActionRewrite(
    public val hostnames: List<GetGatewayRouteSpecHttpRouteActionRewriteHostname>,
    public val paths: List<GetGatewayRouteSpecHttpRouteActionRewritePath>,
    public val prefixes: List<GetGatewayRouteSpecHttpRouteActionRewritePrefix>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetGatewayRouteSpecHttpRouteActionRewrite): GetGatewayRouteSpecHttpRouteActionRewrite = GetGatewayRouteSpecHttpRouteActionRewrite(
            hostnames = javaType.hostnames().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttpRouteActionRewriteHostname.Companion.toKotlin(args0)
                })
            }),
            paths = javaType.paths().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttpRouteActionRewritePath.Companion.toKotlin(args0)
                })
            }),
            prefixes = javaType.prefixes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttpRouteActionRewritePrefix.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
